@@ -1,3 +1,4 @@
+import sys
 import random
 random.seed(0)
 import numpy as np
@@ -13,6 +14,7 @@ from onnx2tf.utils.common_functions import (
     inverted_operation_enable_disable,
     make_tf_node_info,
 )
+from onnx2tf.utils.colors import Color
 
 
 @print_node_info
@@ -49,6 +51,16 @@ def make_node(
     input_tensor = tf_layers_dict[graph_node_input.name]['tf_node'] \
         if isinstance(graph_node_input, gs.Variable) else graph_node_input
 
+    if len(graph_node.outputs) > 1:
+        print(
+            f'{Color.RED}ERROR:{Color.RESET} '+
+            f'MaxPoolWithArgmax is not yet implemented. '+
+            f'Pull requests are welcome. \n'+
+            f'https://github.com/onnx/onnx-tensorflow/blob/f9ebc35dba8a9555112a8d0b84f5a3d51278cca9/onnx_tf/handlers/backend/dilated_pooling.py#L544 \n'+
+            f'graph_node.name: {graph_node.name}'
+        )
+        sys.exit(1)
+
     filter = None
     strides = None
     dilations = None
@@ -73,7 +85,7 @@ def make_node(
         pads = graph_node.attrs.get('pads', [0] * spatial_size * 2)
         # if is_known_shape and pads != [0] * spatial_size * 2:
         if pads != [0] * spatial_size * 2:
-            in_shape = input_tensor.get_shape()
+            in_shape = input_tensor.shape
             same_paddings = calc_pads_same_pooling(
                 in_spatial_shape=in_shape[1:x_rank - 1],
                 kernel_shape=kernel_shape,
@@ -132,7 +144,7 @@ def make_node(
             input_tensor_dtype,
         )
         pooled_tensor = tf.nn.dilation2d(
-            input=input_tensor,
+            input=padded_tensor,
             filters=filter,
             strides=strides,
             dilations=dilations,
@@ -145,7 +157,7 @@ def make_node(
         # if strides == 1 and not LpPool use tf.nn.pool directly
         if strides == [1] * spatial_size:
             pooled_tensor = tf.nn.pool(
-                input=input_tensor,
+                input=padded_tensor,
                 window_shape=kernel_shape,
                 dilations=dilations,
                 strides=strides,
@@ -156,7 +168,7 @@ def make_node(
         else:
             # othwerwise check the pooling_type and use the correct op
             pooled_tensor = tf.nn.max_pool(
-                input=input_tensor,
+                input=padded_tensor,
                 ksize=kernel_shape,
                 strides=strides,
                 padding=padding_,
